@@ -25,14 +25,9 @@
 #include <e-util/e-icon-factory.h>
 #include <e-util/e-util-private.h>
 
-#include <glib.h>
 #include <glib/gi18n.h>
 #include <libgnome/gnome-util.h>
 #include <misc/e-gui-utils.h>
-#include <gtk/gtkcombo.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtklabel.h>
 #include <string.h>
 #include <stdlib.h>
 #include <locale.h>
@@ -225,7 +220,7 @@ static char * countries [] = {
 	N_("Guatemala"),
 	N_("Guernsey"),
 	N_("Guinea"),
-	N_("Guinea-bissau"),
+	N_("Guinea-Bissau"),
 	N_("Guyana"),
 	N_("Haiti"),
 	N_("Heard And McDonald Islands"),
