@@ -14,13 +14,13 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 #ifndef __E_MINICARD_H__
 #define __E_MINICARD_H__
 
-#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
 #include "addressbook/gui/contact-editor/eab-editor.h"
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libebook/e-contact.h>
@@ -60,10 +60,10 @@ enum _EMinicardFocusType {
 struct _EMinicard
 {
 	GnomeCanvasGroup parent;
-	
+
 	/* item specific fields */
 	EContact *contact;
-	
+
 	GnomeCanvasItem *rect;
 	GnomeCanvasItem *header_rect;
 	GnomeCanvasItem *header_text;
@@ -107,7 +107,7 @@ struct _EMinicardClass
 };
 
 typedef struct _EMinicardField EMinicardField;
-                                                                               
+
 struct _EMinicardField {
 	EContactField field;
 	GnomeCanvasItem *label;
