@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-contact-print.h
  * Copyright (C) 2000  Ximian, Inc.
  * Author: Chris Lahey <clahey@ximian.com>
@@ -22,8 +22,7 @@
 #ifndef E_CONTACT_PRINT_H
 #define E_CONTACT_PRINT_H
 
-#include <glib.h>
-#include <gtk/gtkprintoperation.h>
+#include <gtk/gtk.h>
 #include <libebook/e-book.h>
 #include "e-contact-print-types.h"
 
