@@ -28,6 +28,8 @@
 
 #define G_LOG_DOMAIN "etodoconduit"
 
+#include <glib/gi18n.h>
+#include <libgnome/gnome-config.h>
 #include <libecal/e-cal-types.h>
 #include <libecal/e-cal.h>
 #include <libecal/e-cal-time-util.h>
