@@ -22,9 +22,9 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <bonobo/bonobo-exception.h>
-#include <bonobo/bonobo-i18n.h>
 #include <evolution-calendar.h>
 #include <libedataserver/e-url.h>
 #include <libecal/e-cal.h>
@@ -281,6 +281,7 @@ edit_existing (OpenClient *oc, const char *uid)
 	/* Set the object on the editor */
 	comp_editor_edit_comp (editor, comp);
 	comp_editor_focus (editor);
+	g_object_unref (comp);
 
 	oc->editor_count++;
 	g_signal_connect (editor, "destroy", G_CALLBACK (editor_destroy_cb), oc);
@@ -401,31 +402,31 @@ cal_opened_cb (ECal *client, ECalendarStatus status, gpointer data)
 	case E_CALENDAR_STATUS_NO_SUCH_CALENDAR:
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 _("Error while opening the calendar"));
+						 "%s", _("Error while opening the calendar"));
 		break;
 
 	case E_CALENDAR_STATUS_PROTOCOL_NOT_SUPPORTED:
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 _("Method not supported when opening the calendar"));
+						 "%s", _("Method not supported when opening the calendar"));
 		break;
 
 	case E_CALENDAR_STATUS_PERMISSION_DENIED :
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 _("Permission denied to open the calendar"));
+						 "%s", _("Permission denied to open the calendar"));
 		break;
 
 	case E_CALENDAR_STATUS_AUTHENTICATION_FAILED :
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 _("Authentication Failed"));
+						 "%s", _("Authentication Failed"));
 		break;
 
 	default:
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 _("Unknown error"));
+						 "%s", _("Unknown error"));
 		return;
 	}
 
