@@ -22,8 +22,7 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtkmessagedialog.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 #include "copy-source-dialog.h"
 #include "select-source-dialog.h"
 #include "common/authentication.h"
