@@ -22,8 +22,7 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <e-util/e-icon-factory.h>
