@@ -16,18 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <gtk/gtksignal.h>
-#include <gtk/gtkcombo.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtklabel.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <libical/ical.h>
 #include <glade/glade.h>
 #include <misc/e-map.h>
@@ -49,7 +45,7 @@ struct _EDelegateDialogPrivate {
 	GtkWidget *addressbook;
 
 	ENameSelector *name_selector;
-	GtkWidget *entry;	
+	GtkWidget *entry;
 };
 
 static const char *section_name = "Delegate To";
@@ -167,7 +163,7 @@ e_delegate_dialog_construct (EDelegateDialog *edd, const char *name, const char
 	e_name_selector_model_peek_section (name_selector_model, section_name, NULL, &destination_store);
 	e_destination_store_append_destination (destination_store, dest);
 	g_object_unref (dest);
-		
+
 	g_signal_connect((priv->addressbook), "clicked",
 			    G_CALLBACK (addressbook_clicked_cb), edd);
 
@@ -193,7 +189,7 @@ get_widgets (EDelegateDialog *edd)
 
 	priv->app		= GW ("delegate-dialog");
 	priv->hbox              = GW ("delegate-hbox");
-	priv->addressbook	= GW ("addressbook");	
+	priv->addressbook	= GW ("addressbook");
 
 	return (priv->app
 		&& priv->hbox
@@ -206,7 +202,7 @@ addressbook_clicked_cb (GtkWidget *widget, gpointer data)
 	EDelegateDialog *edd = data;
 	EDelegateDialogPrivate *priv;
 	ENameSelectorDialog *name_selector_dialog;
-	
+
 	priv = edd->priv;
 
 	name_selector_dialog = e_name_selector_peek_dialog (priv->name_selector);
@@ -251,7 +247,7 @@ e_delegate_dialog_get_delegate		(EDelegateDialog  *edd)
 	EDestinationStore *destination_store;
 	GList *destinations;
 	EDestination *destination;
-	
+
 	g_return_val_if_fail (edd != NULL, NULL);
 	g_return_val_if_fail (E_IS_DELEGATE_DIALOG (edd), NULL);
 
@@ -269,7 +265,7 @@ e_delegate_dialog_get_delegate		(EDelegateDialog  *edd)
 		g_free (priv->address);
 		priv->address = g_strdup (e_destination_get_email (destination));
 	}
-	
+
 	g_list_free (destinations);
 	return g_strdup (priv->address);
 }
@@ -283,7 +279,7 @@ e_delegate_dialog_get_delegate_name		(EDelegateDialog  *edd)
 	EDestinationStore *destination_store;
 	GList *destinations;
 	EDestination *destination;
-	
+
 	g_return_val_if_fail (edd != NULL, NULL);
 	g_return_val_if_fail (E_IS_DELEGATE_DIALOG (edd), NULL);
 
@@ -301,7 +297,7 @@ e_delegate_dialog_get_delegate_name		(EDelegateDialog  *edd)
 		g_free (priv->name);
 		priv->name = g_strdup (e_destination_get_name (destination));
 	}
-	
+
 	g_list_free (destinations);
 	return g_strdup (priv->name);
 }
