@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -35,13 +35,10 @@
 #include <math.h>
 #include <time.h>
 #include <sys/stat.h>
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkvscrollbar.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <glib/gstdio.h>
+#include <gdk/gdkkeysyms.h>
 #include <misc/e-gui-utils.h>
 #include <table/e-table-memory-store.h>
 #include <table/e-cell-checkbox.h>
@@ -50,7 +47,6 @@
 #include <table/e-cell-combo.h>
 #include <misc/e-popup-menu.h>
 #include <misc/e-cell-date-edit.h>
-#include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-util.h>
 #include <e-util/e-categories-config.h>
@@ -89,7 +85,7 @@ static gboolean  e_cal_list_view_on_table_right_click   (GtkWidget *table, gint
 							 GdkEvent *event, gpointer data);
 static void e_cal_list_view_cursor_change_cb (ETable *etable, gint row, gpointer data);
 
-G_DEFINE_TYPE (ECalListView, e_cal_list_view, E_TYPE_CALENDAR_VIEW);
+G_DEFINE_TYPE (ECalListView, e_cal_list_view, E_TYPE_CALENDAR_VIEW)
 
 static void
 e_cal_list_view_class_init (ECalListViewClass *class)
@@ -235,6 +231,8 @@ setup_e_table (ECalListView *cal_list_view)
 	e_table_extras_add_cell (extras, "dateedit", popup_cell);
 	cal_list_view->dates_cell = E_CELL_DATE_EDIT (popup_cell);
 
+	gtk_widget_hide (E_CELL_DATE_EDIT (popup_cell)->none_button);
+
 	e_cell_date_edit_set_get_time_callback (E_CELL_DATE_EDIT (popup_cell),
 						get_current_time_cb,
 						cal_list_view, NULL);
@@ -291,7 +289,7 @@ setup_e_table (ECalListView *cal_list_view)
 			  "double_click", G_CALLBACK (e_cal_list_view_on_table_double_click), cal_list_view);
 	g_signal_connect (e_table_scrolled_get_table (cal_list_view->table_scrolled),
 			  "right-click", G_CALLBACK (e_cal_list_view_on_table_right_click), cal_list_view);
-	g_signal_connect_after (e_table_scrolled_get_table (cal_list_view->table_scrolled), 
+	g_signal_connect_after (e_table_scrolled_get_table (cal_list_view->table_scrolled),
 				"cursor_change", G_CALLBACK (e_cal_list_view_cursor_change_cb), cal_list_view);
 
 	/* Attach and show widget */
@@ -320,7 +318,7 @@ e_cal_list_view_new (void)
 {
 	ECalListView *cal_list_view;
 	ECalModel *model;
-	
+
 	model = E_CAL_MODEL (e_cal_model_calendar_new ());
 	e_cal_model_set_flags (model, E_CAL_MODEL_FLAGS_EXPAND_RECURRENCES);
 
@@ -386,16 +384,16 @@ e_cal_list_view_popup_menu (GtkWidget *widget)
 	return TRUE;
 }
 
-static gboolean 
-find_meeting (icalcomponent *icalcomp) 
+static gboolean
+find_meeting (icalcomponent *icalcomp)
 {
 	icalproperty *prop = NULL;
 
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
-	
+
 	return prop ? TRUE: FALSE;
 }
-		
+
 
 static gboolean
 e_cal_list_view_on_table_double_click (GtkWidget *table, gint row, gint col, GdkEvent *event,
@@ -406,7 +404,7 @@ e_cal_list_view_on_table_double_click (GtkWidget *table, gint row, gint col, Gdk
 
 	comp_data = e_cal_model_get_component_at (e_calendar_view_get_model (E_CALENDAR_VIEW (cal_list_view)), row);
 	e_calendar_view_edit_appointment (E_CALENDAR_VIEW (cal_list_view), comp_data->client,
-					  comp_data->icalcomp, find_meeting (comp_data->icalcomp));	
+					  comp_data->icalcomp, find_meeting (comp_data->icalcomp));
 
 	return TRUE;
 }
