@@ -23,7 +23,7 @@
 #ifndef _E_MEETING_LIST_VIEW_H_
 #define _E_MEETING_LIST_VIEW_H_
 
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 #include "e-meeting-store.h"
 #include <libedataserverui/e-name-selector.h>
 
@@ -57,7 +57,7 @@ GType      e_meeting_list_view_get_type (void);
 
 EMeetingListView *e_meeting_list_view_new (EMeetingStore *store);
 
-void       e_meeting_list_view_column_set_visible (EMeetingListView *emlv, const gchar *col_name, gboolean visible);
+void       e_meeting_list_view_column_set_visible (EMeetingListView *emlv, EMeetingStoreColumns column, gboolean visible);
 
 void       e_meeting_list_view_edit (EMeetingListView *emlv, EMeetingAttendee *attendee);
 
