@@ -34,10 +34,10 @@
 
 #include <sys/stat.h>
 #include <unistd.h>
-#include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
-#include <gnome.h>
+#include <gdk/gdkkeysyms.h>
+#include <libgnome/gnome-url.h>
 #include <widgets/misc/e-gui-utils.h>
 #include <table/e-cell-checkbox.h>
 #include <table/e-cell-toggle.h>
@@ -555,6 +555,7 @@ copy_row_cb (int model_row, gpointer data)
 					     icalcomponent_new_clone (child));
 		icalcomponent_free (child);
 	}
+	g_free (comp_str);
 }
 
 static void
@@ -610,6 +611,7 @@ e_memo_table_copy_clipboard (EMemoTable *memo_table)
 
 	/* free memory */
 	icalcomponent_free (memo_table->tmp_vcal);
+	g_free (comp_str);
 	memo_table->tmp_vcal = NULL;
 }
 
@@ -764,6 +766,7 @@ open_memo (EMemoTable *memo_table, ECalModelComponent *comp_data)
 		medit = COMP_EDITOR (memo_editor_new (comp_data->client, flags));
 
 		comp_editor_edit_comp (medit, comp);
+		g_object_unref (comp);
 
 		e_comp_editor_registry_add (comp_editor_registry, medit, FALSE);
 	}
