@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Damon Chaplin <damon@ximian.com>
  *	    Ettore Perazzoli
@@ -26,10 +26,7 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtksignal.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-dialog.h>
@@ -39,6 +36,7 @@
 #include <bonobo/bonobo-ui-util.h>
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-print.h>
+#include <e-util/e-icon-factory.h>
 #include <e-util/e-util-private.h>
 
 #include "calendar-config.h"
@@ -132,7 +130,7 @@ memos_control_sensitize_commands (BonoboControl *control, EMemos *memos, int n_s
 	ECalModel *model;
 
 	uic = bonobo_control_get_ui_component (control);
-	g_assert (uic != NULL);
+	g_return_if_fail (uic != NULL);
 
 	if (bonobo_ui_component_get_container (uic) == CORBA_OBJECT_NIL)
 		return;
@@ -183,6 +181,23 @@ static BonoboUIVerb verbs [] = {
 	BONOBO_UI_VERB_END
 };
 
+static EPixmap pixmaps [] = {
+	E_PIXMAP ("/commands/MemosCopy", "edit-copy", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/MemosCut", "edit-cut", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/MemosDelete", "edit-delete", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/MemosPaste", "edit-paste", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/MemosPrint", "document-print", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/MemosPrintPreview", "document-print-preview", E_ICON_SIZE_MENU),
+
+	E_PIXMAP ("/Toolbar/Cut", "edit-cut", E_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Copy", "edit-copy", E_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Paste", "edit-paste", E_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Print", "document-print", E_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Delete", "edit-delete", E_ICON_SIZE_LARGE_TOOLBAR),
+
+	E_PIXMAP_END
+};
+
 void
 memos_control_activate (BonoboControl *control, EMemos *memos)
 {
@@ -194,7 +209,7 @@ memos_control_activate (BonoboControl *control, EMemos *memos)
 	char *xmlfile;
 
 	uic = bonobo_control_get_ui_component (control);
-	g_assert (uic != NULL);
+	g_return_if_fail (uic != NULL);
 
 	remote_uih = bonobo_control_get_remote_ui_container (control, NULL);
 	bonobo_ui_component_set_container (uic, remote_uih, NULL);
@@ -215,6 +230,8 @@ memos_control_activate (BonoboControl *control, EMemos *memos)
 			       NULL);
 	g_free (xmlfile);
 
+	e_pixmaps_update (uic, pixmaps);
+
 	e_memos_setup_view_menus (memos, uic);
 
 	/* Signals from the memos widget; also sensitize the menu items as appropriate */
@@ -236,7 +253,7 @@ memos_control_deactivate (BonoboControl *control, EMemos *memos)
 {
 	BonoboUIComponent *uic = bonobo_control_get_ui_component (control);
 
-	g_assert (uic != NULL);
+	g_return_if_fail (uic != NULL);
 
 	e_memos_set_ui_component (memos, NULL);
 
