@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -45,11 +45,11 @@ static void em_filter_editor_finalise (GObject *obj);
 static RuleEditorClass *parent_class = NULL;
 
 
-GtkType
+GType
 em_filter_editor_get_type (void)
 {
-	static GtkType type = 0;
-	
+	static GType type = 0;
+
 	if (!type) {
 		static const GTypeInfo info = {
 			sizeof (EMFilterEditorClass),
@@ -62,10 +62,10 @@ em_filter_editor_get_type (void)
 			0,    /* n_preallocs */
 			(GInstanceInitFunc) em_filter_editor_init,
 		};
-		
+
 		type = g_type_register_static (RULE_TYPE_EDITOR, "EMFilterEditor", &info, 0);
 	}
-	
+
 	return type;
 }
 
@@ -74,11 +74,11 @@ em_filter_editor_class_init (EMFilterEditorClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 	RuleEditorClass *re_class = (RuleEditorClass *) klass;
-	
+
 	parent_class = g_type_class_ref (rule_editor_get_type ());
-	
+
 	gobject_class->finalize = em_filter_editor_finalise;
-	
+
 	/* override methods */
 	re_class->create_rule = create_rule;
 }
@@ -99,7 +99,7 @@ em_filter_editor_finalise (GObject *obj)
  * em_filter_editor_new:
  *
  * Create a new EMFilterEditor object.
- * 
+ *
  * Return value: A new #EMFilterEditor object.
  **/
 EMFilterEditor *
@@ -117,7 +117,7 @@ em_filter_editor_new (EMFilterContext *fc, const EMFilterSource *source_names)
 
 	em_filter_editor_construct (fe, fc, gui, source_names);
 	g_object_unref (gui);
-	
+
 	return fe;
 }
 
@@ -125,10 +125,10 @@ static void
 select_source (GtkMenuItem *mi, EMFilterEditor *fe)
 {
 	char *source;
-	
+
 	source = g_object_get_data(G_OBJECT(mi), "source");
-	g_assert (source);
-	
+	g_return_if_fail (source);
+
 	rule_editor_set_source ((RuleEditor *)fe, source);
 }
 
@@ -137,11 +137,12 @@ em_filter_editor_construct (EMFilterEditor *fe, EMFilterContext *fc, GladeXML *g
 {
 	GtkWidget *menu, *item, *omenu;
 	int i;
-	
+	GtkTreeViewColumn *column;
+
         omenu = glade_xml_get_widget (gui, "filter_source");
 	gtk_option_menu_remove_menu (GTK_OPTION_MENU (omenu));
 	menu = gtk_menu_new ();
-	
+
 	for (i = 0; source_names[i].source; i++) {
 		item = gtk_menu_item_new_with_label(source_names[i].name);
 		g_object_set_data_full((GObject *)item, "source", g_strdup(source_names[i].source), g_free);
@@ -151,8 +152,12 @@ em_filter_editor_construct (EMFilterEditor *fe, EMFilterContext *fc, GladeXML *g
 	}
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu), menu);
 	gtk_widget_show (omenu);
-	
+
 	rule_editor_construct ((RuleEditor *) fe, (RuleContext *) fc, gui, source_names[0].source, _("_Filter Rules"));
+
+	/* Show the Enabled column, we support it here */
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW (RULE_EDITOR (fe)->list), 0);
+	gtk_tree_view_column_set_visible (column, TRUE);
 }
 
 static FilterRule *
@@ -160,13 +165,13 @@ create_rule (RuleEditor *re)
 {
 	FilterRule *rule = filter_rule_new ();
 	FilterPart *part;
-	
+
 	/* create a rule with 1 part & 1 action in it */
 	rule = (FilterRule *)em_filter_rule_new ();
 	part = rule_context_next_part (re->context, NULL);
 	filter_rule_add_part (rule, filter_part_clone (part));
 	part = em_filter_context_next_action ((EMFilterContext *)re->context, NULL);
 	em_filter_rule_add_action ((EMFilterRule *)rule, filter_part_clone (part));
-	
+
 	return rule;
 }
