@@ -339,8 +339,14 @@ em_folder_tree_model_load_state (EMFolderTreeModel *model, const char *filename)
 	if (model->state)
 		xmlFreeDoc (model->state);
 
-	if ((model->state = e_xml_parse_file (filename)))
-		return;
+	if ((model->state = e_xml_parse_file (filename)) != NULL) {
+		node = xmlDocGetRootElement (model->state);
+		if (!node || strcmp ((char *)node->name, "tree-state") != 0) {
+			/* it is not expected XML file, thus free it and use the default */
+			xmlFreeDoc (model->state);
+		} else
+			return;
+	}
 
 	/* setup some defaults - expand "Local Folders" and "Search Folders" */
 	model->state = xmlNewDoc ((const unsigned char *)"1.0");
@@ -851,6 +857,23 @@ em_folder_tree_model_add_store (EMFolderTreeModel *model, CamelStore *store, con
 	gtk_tree_path_free (path);
 }
 
+void
+em_folder_tree_model_signal_block (EMFolderTreeModel *model, CamelStore *store, gboolean block)
+{
+	struct _EMFolderTreeModelStoreInfo *si;
+
+	si = g_hash_table_lookup (model->store_hash, store);
+	if (!si)
+		return;
+
+	if (block) {
+		if (si->created_id) 
+			camel_object_unhook_event (store, "folder_created", CAMEL_CALLBACK (folder_created_cb), model);
+		si->created_id = 0;
+	} else {
+		si->created_id = camel_object_hook_event (store, "folder_created", CAMEL_CALLBACK (folder_created_cb), model);
+	}
+}
 
 static void
 em_folder_tree_model_remove_uri (EMFolderTreeModel *model, const char *uri)
