@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -24,7 +24,7 @@
 #ifndef __EM_FOLDER_TREE_H__
 #define __EM_FOLDER_TREE_H__
 
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 #include <camel/camel-store.h>
 
 #include "mail/em-folder-tree-model.h"
@@ -61,7 +61,7 @@ struct _EMFolderTree {
 
 struct _EMFolderTreeClass {
 	GtkVBoxClass parent_class;
-	
+
 	/* signals */
 	void (* folder_activated) (EMFolderTree *emft, const char *full_name, const char *uri);
 	void (* folder_selected) (EMFolderTree *emft, const char *full_name, const char *uri, guint32 flags);
@@ -78,11 +78,11 @@ void em_folder_tree_set_multiselect (EMFolderTree *emft, gboolean mode);
 void em_folder_tree_set_excluded(EMFolderTree *emft, guint32 flags);
 void em_folder_tree_set_excluded_func(EMFolderTree *emft, EMFTExcludeFunc exclude, void *data);
 
-void em_folder_tree_set_selected_list (EMFolderTree *emft, GList *list);
+void em_folder_tree_set_selected_list (EMFolderTree *emft, GList *list, gboolean expand_only);
 GList *em_folder_tree_get_selected_uris (EMFolderTree *emft);
 GList *em_folder_tree_get_selected_paths (EMFolderTree *emft);
 
-void em_folder_tree_set_selected (EMFolderTree *emft, const char *uri);
+void em_folder_tree_set_selected (EMFolderTree *emft, const char *uri, gboolean expand_only);
 void em_folder_tree_select_next_path (EMFolderTree *emft, gboolean skip_read_folders);
 void em_folder_tree_select_prev_path (EMFolderTree *emft, gboolean skip_read_folders);
 char *em_folder_tree_get_selected_uri (EMFolderTree *emft);
