@@ -20,26 +20,38 @@
  *
  */
 
+#ifndef EM_FOLDER_VIEW_H
+#define EM_FOLDER_VIEW_H
 
-#ifndef _EM_FOLDER_VIEW_H
-#define _EM_FOLDER_VIEW_H
-
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkprintoperation.h>
+#include <gtk/gtk.h>
 #include "mail/em-popup.h"
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+/* Standard GObject macros */
+#define EM_TYPE_FOLDER_VIEW \
+	(em_folder_view_get_type ())
+#define EM_FOLDER_VIEW(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST \
+	((obj), EM_TYPE_FOLDER_VIEW, EMFolderView))
+#define EM_FOLDER_VIEW_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_CAST \
+	((cls), EM_TYPE_FOLDER_VIEW, EMFolderViewClass))
+#define EM_IS_FOLDER_VIEW(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE \
+	((obj), EM_TYPE_FOLDER_VIEW))
+#define EM_IS_FOLDER_VIEW_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_TYPE \
+	((cls), EM_TYPE_FOLDER_VIEW))
+#define EM_FOLDER_VIEW_GET_CLASS(obj) \
+	(G_TYPE_INSTANCE_GET_CLASS \
+	((obj), EM_TYPE_FOLDER_VIEW, EMFolderViewClass))
+
+G_BEGIN_DECLS
 
 struct _MessageList;
 struct _EMFormatHTMLDisplay;
 struct _CamelFolder;
 struct _CamelMedium;
 
-#define EM_FOLDER_VIEW_GET_CLASS(emfv)  ((EMFolderViewClass *) G_OBJECT_GET_CLASS (emfv))
-
 typedef struct _EMFolderView EMFolderView;
 typedef struct _EMFolderViewClass EMFolderViewClass;
 
@@ -142,8 +154,6 @@ void em_folder_view_set_statusbar(EMFolderView *emfv, gboolean statusbar);
 void em_folder_view_set_hide_deleted(EMFolderView *emfv, gboolean status);
 void em_folder_view_setup_view_instance (EMFolderView *emfv);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
-#endif /* ! _EM_FOLDER_VIEW_H */
+#endif /* EM_FOLDER_VIEW_H */
