@@ -27,19 +27,9 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <glib.h>
-
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkcheckmenuitem.h>
-#include <gtk/gtkradiomenuitem.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkimage.h>
+#include <gtk/gtk.h>
 
 #include <libgnome/gnome-url.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 
 #include "em-menu.h"
 #include "libedataserver/e-msgport.h"
