@@ -396,7 +396,7 @@ lookup_addressbook(CamelSession *session, const char *name)
 
 	addr = camel_internet_address_new ();
 	camel_address_decode ((CamelAddress *)addr, name);
-	ret = em_utils_in_addressbook(addr);
+	ret = em_utils_in_addressbook (addr, mail_config_get_lookup_book_local_only ());
 	camel_object_unref (addr);
 
 	return ret;
@@ -497,7 +497,7 @@ main_get_filter_driver (CamelSession *session, const char *type, CamelException
 
 	gconf = mail_config_get_gconf_client ();
 
-	user = g_strdup_printf ("%s/mail/filters.xml", mail_component_peek_base_directory (mail_component_peek ()));
+	user = g_strdup_printf ("%s/filters.xml", mail_component_peek_base_directory (mail_component_peek ()));
 	system = g_build_filename (EVOLUTION_PRIVDATADIR, "filtertypes.xml", NULL);
 	fc = (RuleContext *) em_filter_context_new ();
 	rule_context_load (fc, system, user);
@@ -548,6 +548,10 @@ main_get_filter_driver (CamelSession *session, const char *type, CamelException
 			g_string_truncate (fsearch, 0);
 			g_string_truncate (faction, 0);
 
+			/* skip disabled rules */
+			if (!rule->enabled)
+				continue;
+
 			filter_rule_build_code (rule, fsearch);
 			em_filter_rule_build_action ((EMFilterRule *) rule, faction);
 			camel_filter_driver_add_rule (driver, rule->name, fsearch->str, faction->str);
