@@ -24,8 +24,7 @@
 #ifndef _MESSAGE_LIST_H_
 #define _MESSAGE_LIST_H_
 
-#include <gtk/gtkobject.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 #include <table/e-table-simple.h>
 #include <table/e-tree-scrolled.h>
@@ -114,10 +113,6 @@ struct _MessageList {
 	/* Current search string, or %NULL */
 	char *search;
 
-	/* which message uid should be left in the list even not in a search after rebuild;
-	   rebuild will clear the value to NULL */
-	char *ensure_uid;
-
 	/* are we regenerating the message_list because set_folder was just called? */
 	guint just_set_folder : 1;
 
@@ -176,7 +171,7 @@ typedef enum {
 	MESSAGE_LIST_SELECT_WRAP = 1<<1, /* option bit */
 } MessageListSelectDirection;
 
-GtkType        message_list_get_type   (void);
+GType          message_list_get_type   (void);
 GtkWidget     *message_list_new        (void);
 void           message_list_set_folder (MessageList *message_list, CamelFolder *camel_folder, const char *uri, gboolean outgoing);
 
@@ -225,7 +220,6 @@ void           message_list_set_threaded_collapse_all (MessageList *ml);
 
 void	       message_list_set_hidedeleted (MessageList *ml, gboolean hidedeleted);
 void	       message_list_set_search (MessageList *ml, const char *search);
-void	       message_list_ensure_message (MessageList *ml, const char *uid);
 
 void           message_list_save_state (MessageList *ml);
 
