@@ -23,14 +23,10 @@
 #endif
 
 #include <string.h>
-#include <glib.h>
 #include <libedataserverui/e-name-selector.h>
 #include <libedataserverui/e-contact-store.h>
 #include "exchange-operations.h"
 #include <e-util/e-error.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtk.h>
 #include <libgnome/libgnome.h>
 #include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
