@@ -28,18 +28,6 @@
 #include <stdlib.h>
 #include <glib/gi18n.h>
 #include <glade/glade.h>
-#include <glib/gmain.h>
-
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtk.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkcellrenderertoggle.h>
-#include <gtk/gtkcellrenderertext.h>
 
 #include <libedataserverui/e-contact-store.h>
 
@@ -943,7 +931,7 @@ proxy_add_account (GtkWidget *button, EAccount *account)
 	gtk_widget_show (GTK_WIDGET (priv->main));
 
 	name_selector_model = e_name_selector_peek_model (priv->proxy_name_selector);
-	e_name_selector_model_add_section (name_selector_model, "Add User", "Add User", NULL);
+	e_name_selector_model_add_section (name_selector_model, "Add User", _("Add User"), NULL);
 
 	name_selector_entry = e_name_selector_peek_section_entry (priv->proxy_name_selector, "Add User");
 	g_signal_connect (name_selector_entry, "changed",
