@@ -27,8 +27,7 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <glib.h>
-
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 #include <glade/glade.h>
@@ -39,8 +38,6 @@
 #include <libgnomeui/gnome-druid-page-edge.h>
 #include <libgnomeui/gnome-druid-page-standard.h>
 
-#include <gtk/gtkfilechooserbutton.h>
-
 #include "misc/e-gui-utils.h"
 
 #include "e-util/e-dialog-utils.h"
