@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -31,12 +31,9 @@
 #include "cert-trust-dialog.h"
 #include "ca-trust-dialog.h"
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtklabel.h>
+#include <gtk/gtk.h>
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <glade/glade.h>
 
 #include "e-util/e-util-private.h"
@@ -92,7 +89,7 @@ ctd_response(GtkWidget *w, guint id, CertTrustDialogData *data)
 					   e_cert_trust_has_trusted_ca (icert->trust, TRUE,  FALSE, FALSE),
 					   e_cert_trust_has_trusted_ca (icert->trust, FALSE, TRUE,  FALSE),
 					   e_cert_trust_has_trusted_ca (icert->trust, FALSE, FALSE, TRUE));
-						   
+
 		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
 			gboolean trust_ssl, trust_email, trust_objsign;
 
@@ -105,7 +102,7 @@ ctd_response(GtkWidget *w, guint id, CertTrustDialogData *data)
 						   trust_ssl,
 						   trust_email,
 						   trust_objsign);
-				
+
 			CERT_ChangeCertTrust(CERT_GetDefaultCertDB(), icert, &trust);
 		}
 
