@@ -42,21 +42,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkarrow.h>
-#include <gtk/gtkbbox.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkcomboboxentry.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkdrawingarea.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkhbbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkmessagedialog.h>
 #include <atk/atkrelation.h>
 #include <atk/atkrelationset.h>
 #include <glib/gi18n.h>
@@ -451,8 +436,7 @@ create_children			(EDateEdit	*dedit)
 	g_signal_connect (priv->cal_popup, "button_press_event",
 			  G_CALLBACK (on_date_popup_button_press),
 			  dedit);
-	gtk_window_set_policy (GTK_WINDOW (priv->cal_popup),
-			       FALSE, FALSE, TRUE);
+	gtk_window_set_resizable (GTK_WINDOW (priv->cal_popup), TRUE);
 
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
