@@ -29,11 +29,6 @@
 #include "e-dropdown-button.h"
 
 #include <stdio.h>
-#include <gtk/gtkarrow.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkwidget.h>
 #include <libgnomeui/gnome-popup-menu.h>
 
 struct _EDropdownButtonPrivate {
@@ -207,9 +202,9 @@ e_dropdown_button_construct (EDropdownButton *dropdown_button,
 
 	priv->menu = GTK_WIDGET (menu);
 
-	gtk_signal_connect_while_alive (GTK_OBJECT (priv->menu), "deactivate",
-					G_CALLBACK (menu_deactivate_cb),
-					dropdown_button, GTK_OBJECT (dropdown_button));
+	g_signal_connect_object (priv->menu, "deactivate",
+				 G_CALLBACK (menu_deactivate_cb),
+				 dropdown_button, 0);
 }
 
 /**
