@@ -14,14 +14,13 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 #ifndef __E_SEARCH_BAR_H__
 #define __E_SEARCH_BAR_H__
 
-#include <gtk/gtkhbox.h>
-#include <gtk/gtktooltips.h>
+#include <gtk/gtk.h>
 
 #include <bonobo/bonobo-ui-component.h>
 
@@ -60,7 +59,7 @@ typedef struct {
 typedef struct _ESearchBar       ESearchBar;
 typedef struct _ESearchBarClass  ESearchBarClass;
 
-typedef void (*ESearchBarMenuFunc)(ESearchBar *esb, ESearchBarItem *menu_items );
+typedef void (*ESearchBarMenuFunc)(ESearchBar *esb, ESearchBarItem *menu_items);
 
 struct _ESearchBar
 {
@@ -69,12 +68,12 @@ struct _ESearchBar
 	BonoboUIComponent *ui_component;
 
 	GSList *menu_items;
-	
+
 	/* item specific fields */
 	GtkWidget *option;
 	GtkWidget *entry;
 	GtkWidget *suboption; /* an option menu for the choices associated with some options */
-	
+
 	/* PRIVATE */
 	GtkWidget *dropdown_holder;	/* holds the dropdown */
 	GtkWidget *option_menu;
@@ -100,6 +99,9 @@ struct _ESearchBar
 	int        item_id;
 	int        viewitem_id; /* Current View Id */
 	int        scopeitem_id; /* Scope of search */
+	int        last_search_option;
+
+	gboolean block_search;
 };
 
 struct _ESearchBarClass
@@ -139,9 +141,9 @@ void  e_search_bar_add_menu  (ESearchBar     *search_bar,
 
 void  e_search_bar_set_option     (ESearchBar        *search_bar,
 				   ESearchBarItem    *option_items);
-
-void e_search_bar_set_viewoption (ESearchBar *search_bar, 
-				    int option_id, 
+void  e_search_bar_paint (ESearchBar *search_bar);
+void e_search_bar_set_viewoption (ESearchBar *search_bar,
+				    int option_id,
 				    ESearchBarItem *subitems);
 
 void  e_search_bar_set_menu_sensitive  (ESearchBar *search_bar,
@@ -150,6 +152,8 @@ void  e_search_bar_set_menu_sensitive  (ESearchBar *search_bar,
 
 void  e_search_bar_set_item_id  (ESearchBar *search_bar,
 				 int         id);
+void  e_search_bar_set_item_menu (ESearchBar *search_bar,
+				  int id);
 int   e_search_bar_get_item_id  (ESearchBar *search_bar);
 
 int   e_search_bar_get_viewitem_id (ESearchBar *search_bar);
@@ -177,7 +181,7 @@ int e_search_bar_get_search_scope (ESearchBar *search_bar);
 void  e_search_bar_set_text  (ESearchBar *search_bar,
 			      const char *text);
 char *e_search_bar_get_text  (ESearchBar *search_bar);
-
+void e_search_bar_scope_enable (ESearchBar *search_bar, int did, gboolean state);
 G_END_DECLS
 
 
