@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 /*
@@ -59,7 +59,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-#include "e-util/e-i18n.h"
+#include <glib/gi18n.h>
 #include "e-util/e-util.h"
 #include "misc/e-unicode.h"
 
@@ -77,7 +77,7 @@
 #define E_CELL_COMBO_UTF8_KEY		"UTF-8-TEXT"
 
 
-static void e_cell_combo_class_init	(GObjectClass	*object_class);
+static void e_cell_combo_class_init	(ECellComboClass *klass);
 static void e_cell_combo_init		(ECellCombo	*ecc);
 static void e_cell_combo_dispose	(GObject	*object);
 
@@ -114,25 +114,17 @@ static int e_cell_combo_key_press	(GtkWidget	*popup_window,
 static void e_cell_combo_update_cell	(ECellCombo	*ecc);
 static void e_cell_combo_restart_edit	(ECellCombo	*ecc);
 
-
-static ECellPopupClass *parent_class;
-
-
-E_MAKE_TYPE (e_cell_combo, "ECellCombo", ECellCombo,
-	     e_cell_combo_class_init, e_cell_combo_init,
-	     e_cell_popup_get_type())
-
+G_DEFINE_TYPE (ECellCombo, e_cell_combo, E_CELL_POPUP_TYPE)
 
 static void
-e_cell_combo_class_init			(GObjectClass	*object_class)
+e_cell_combo_class_init			(ECellComboClass	*klass)
 {
-	ECellPopupClass *ecpc = (ECellPopupClass *) object_class;
+	ECellPopupClass *ecpc = E_CELL_POPUP_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->dispose = e_cell_combo_dispose;
 
 	ecpc->popup = e_cell_combo_do_popup;
-
-	parent_class = g_type_class_ref (E_CELL_POPUP_TYPE);
 }
 
 
@@ -146,9 +138,9 @@ e_cell_combo_init			(ECellCombo	*ecc)
 	   ever be one popup in use at a time. */
 	ecc->popup_window = gtk_window_new (GTK_WINDOW_POPUP);
 
-	gtk_window_set_policy (GTK_WINDOW (ecc->popup_window),
-			       TRUE, TRUE, FALSE);
-  
+	gtk_window_set_type_hint (GTK_WINDOW (ecc->popup_window), GDK_WINDOW_TYPE_HINT_COMBO);
+	gtk_window_set_resizable (GTK_WINDOW (ecc->popup_window), TRUE);
+
 	frame = gtk_frame_new (NULL);
 	gtk_container_add (GTK_CONTAINER (ecc->popup_window), frame);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
@@ -228,13 +220,13 @@ e_cell_combo_dispose			(GObject *object)
 		gtk_widget_destroy (ecc->popup_window);
 	ecc->popup_window = NULL;
 
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	G_OBJECT_CLASS (e_cell_combo_parent_class)->dispose (object);
 }
 
 
 
 void
-e_cell_combo_set_popdown_strings	(ECellCombo	*ecc, 
+e_cell_combo_set_popdown_strings	(ECellCombo	*ecc,
 					 GList		*strings)
 {
 	GList *elem;
@@ -286,7 +278,7 @@ e_cell_combo_do_popup			(ECellPopup	*ecp,
 
 	error_code = gdk_pointer_grab (ecc->popup_list->window, TRUE,
 				       GDK_ENTER_NOTIFY_MASK |
-				       GDK_BUTTON_PRESS_MASK | 
+				       GDK_BUTTON_PRESS_MASK |
 				       GDK_BUTTON_RELEASE_MASK |
 				       GDK_POINTER_MOTION_HINT_MASK |
 				       GDK_BUTTON1_MOTION_MASK,
@@ -365,7 +357,7 @@ e_cell_combo_show_popup			(ECellCombo	*ecc, int row, int view_col)
 	}
 
 	gtk_widget_set_uposition (ecc->popup_window, x, y);
-	gtk_widget_set_usize (ecc->popup_window, width, height);
+	gtk_widget_set_size_request (ecc->popup_window, width, height);
 	gtk_widget_realize (ecc->popup_window);
 	gdk_window_resize (ecc->popup_window->window, width, height);
 	gtk_widget_show (ecc->popup_window);
@@ -396,11 +388,11 @@ e_cell_combo_get_popup_pos		(ECellCombo	*ecc,
 	gint column_width, row_height, scrollbar_width;
 	double x1, y1;
 	double wx, wy;
-  
+
 	/* This code is practically copied from GtkCombo. */
 	popup  = GTK_SCROLLED_WINDOW (ecc->popup_scrolled_window);
 	popwin = GTK_BIN (ecc->popup_window);
-  
+
 	gdk_window_get_origin (canvas->window, x, y);
 
 	x1 = e_table_header_col_diff (eti->header, 0, view_col + 1);
@@ -435,13 +427,13 @@ e_cell_combo_get_popup_pos		(ECellCombo	*ecc,
 	   the vertical scrollbar in case we need to show that. */
 	screen_width = gdk_screen_width ();
 	avail_width = screen_width - scrollbar_width;
-  
+
 	gtk_widget_size_request (ecc->popup_list, &list_requisition);
-	min_height = MIN (list_requisition.height, 
+	min_height = MIN (list_requisition.height,
 			  popup->vscrollbar->requisition.height);
 	if (!GTK_LIST (ecc->popup_list)->children)
 		list_requisition.height += E_CELL_COMBO_LIST_EMPTY_HEIGHT;
-  
+
 	/* Calculate the desired width. */
 	*width = list_requisition.width
 		+ 2 * popwin->child->style->xthickness
@@ -595,7 +587,7 @@ e_cell_combo_button_release		(GtkWidget	*popup_window,
 	GtkWidget *event_widget;
 
 	event_widget = gtk_get_event_widget ((GdkEvent*) event);
-  
+
 	/* See if the button was released in the list (or its children). */
 	while (event_widget && event_widget != ecc->popup_list)
 		event_widget = event_widget->parent;
@@ -636,6 +628,9 @@ e_cell_combo_key_press			(GtkWidget	*popup_window,
 	    && event->keyval != GDK_3270_Enter)
 		return FALSE;
 
+	if (event->keyval == GDK_Escape && (!ecc->popup_window||!GTK_WIDGET_VISIBLE (ecc->popup_window)))
+		return FALSE;
+
 	gtk_grab_remove (ecc->popup_window);
 	gdk_pointer_ungrab (event->time);
 	gdk_keyboard_ungrab (event->time);
