@@ -24,7 +24,7 @@
 #ifndef __E_TABLE_FIELD_CHOOSER_DIALOG_H__
 #define __E_TABLE_FIELD_CHOOSER_DIALOG_H__
 
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 #include <table/e-table-field-chooser.h>
 #include <table/e-table-header.h>
 
