@@ -398,7 +398,7 @@ e_table_model_pre_change (ETableModel *e_table_model)
 		return;
 
 	d(print_tabs());
-	d(g_print("Emitting pre_change on model 0x%p, a %s.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type)));
+	d(g_print("Emitting pre_change on model 0x%p, a %s.\n", e_table_model, g_type_name (GTK_OBJECT(e_table_model)->klass->type)));
 	d(depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals [MODEL_PRE_CHANGE], 0);
@@ -428,7 +428,7 @@ e_table_model_no_change (ETableModel *e_table_model)
 		return;
 
 	d(print_tabs());
-	d(g_print("Emitting model_no_change on model 0x%p, a %s.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type)));
+	d(g_print("Emitting model_no_change on model 0x%p, a %s.\n", e_table_model, g_type_name (GTK_OBJECT(e_table_model)->klass->type)));
 	d(depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals [MODEL_NO_CHANGE], 0);
@@ -458,7 +458,7 @@ e_table_model_changed (ETableModel *e_table_model)
 		return;
 
 	d(print_tabs());
-	d(g_print("Emitting model_changed on model 0x%p, a %s.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type)));
+	d(g_print("Emitting model_changed on model 0x%p, a %s.\n", e_table_model, g_type_name (GTK_OBJECT(e_table_model)->klass->type)));
 	d(depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals [MODEL_CHANGED], 0);
@@ -485,7 +485,7 @@ e_table_model_row_changed (ETableModel *e_table_model, int row)
 		return;
 
 	d(print_tabs());
-	d(g_print("Emitting row_changed on model 0x%p, a %s, row %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
+	d(g_print("Emitting row_changed on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
 	d(depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals [MODEL_ROW_CHANGED], 0, row);
@@ -513,7 +513,7 @@ e_table_model_cell_changed (ETableModel *e_table_model, int col, int row)
 		return;
 
 	d(print_tabs());
-	d(g_print("Emitting cell_changed on model 0x%p, a %s, row %d, col %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row, col));
+	d(g_print("Emitting cell_changed on model 0x%p, a %s, row %d, col %d.\n", e_table_model, g_type_name (GTK_OBJECT(e_table_model)->klass->type), row, col));
 	d(depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals [MODEL_CELL_CHANGED], 0, col, row);
@@ -541,7 +541,7 @@ e_table_model_rows_inserted (ETableModel *e_table_model, int row, int count)
 		return;
 
 	d(print_tabs());
-	d(g_print("Emitting row_inserted on model 0x%p, a %s, row %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
+	d(g_print("Emitting row_inserted on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
 	d(depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals [MODEL_ROWS_INSERTED], 0, row, count);
@@ -584,7 +584,7 @@ e_table_model_rows_deleted (ETableModel *e_table_model, int row, int count)
 		return;
 
 	d(print_tabs());
-	d(g_print("Emitting row_deleted on model 0x%p, a %s, row %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
+	d(g_print("Emitting row_deleted on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
 	d(depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals [MODEL_ROWS_DELETED], 0, row, count);
